@@ -1,4 +1,4 @@
-oobErrorRate.wsrf <- function(object, tree, ...)
+oobErrorRate.wsrf <- function(object, tree)
 {
     # trees=	a number indicates tree id of the tree to be summarised
     
@@ -18,4 +18,4 @@ oobErrorRate.wsrf <- function(object, tree, ...)
     # return out-of-bag error rates for all individual trees, length of ntrees
     if (is.logical(tree) && tree)
         return(errRates)
-}
\ No newline at end of file
+}
